@@ -5,8 +5,13 @@ hr_area <- function(x, ...) {
 }
 
 #' @export
-hr_area.hr <- function(x, ...) {
-  tibble::as_tibble(sf::st_set_geometry(hr_isopleths(x), NULL))
+#' @rdname hr
+hr_area.hr <- function(x, units = FALSE, ...) {
+  xx <- tibble::as_tibble(sf::st_set_geometry(hr_isopleths(x), NULL))
+  if (!units) {
+    xx$area <- as.numeric(xx$area)
+  }
+  xx
 }
 
 
