@@ -6,10 +6,11 @@ hr_mcp <- function(x, ...) {
 
 #' @export
 #' @rdname hr
-hr_mcp.track_xy <- function(x, levels = 0.95, ...) {
+hr_mcp.track_xy <- function(x, levels = 0.95, keep.data = TRUE, ...) {
 
   # check levels
   checkmate::assert_numeric(levels, lower = 0, upper = 1, min.len = 1)
+  checkmate::assert_logical(keep.data, len = 1)
   levels <- sort(levels)
 
   xy <- x[, c("x_", "y_")]
@@ -19,7 +20,8 @@ hr_mcp.track_xy <- function(x, levels = 0.95, ...) {
   geometry <- lapply(qts, function(i) chull_mcp(xy[sqd <= i, ]))
   geometry <- sf::st_as_sfc(geometry, crs = as.character(get_crs(x)))
   mcps <- sf::st_sf(level = levels, area = sf::st_area(geometry), geometry)
-  mcp <- list(mcp = mcps, levels = levels, estimator = "mcp")
+  mcp <- list(mcp = mcps, levels = levels, estimator = "mcp",
+              data = if (keep.data) x else NULL)
   class(mcp) <- c("mcp", "hr_geom", "hr")
   mcp
 }
